@@ -50,6 +50,8 @@ class MsgFields(ConstantDict):
     WHOIS = "whois"
     WHOIS_RAW = "raw"
 
+    SEEDED_TASK = "seeded"
+
     TASKRESULTS = "tmoids"
 
     TRS_META = "_trs"
@@ -61,10 +63,20 @@ class MsgFields(ConstantDict):
     META_END_TIME = "etime"
     META_SUCCESS = "ok"
     META_RESULT = "r"
-    META_VERSION = "v"
+    META_TASK_NAME = "tname"
+    META_TASK_VERSION = "v"
     META_ERR = "e"
     META_MSG = "m"
 
+    TASKS_HTTP_STATUS = "http_status_task"
+    TASKS_RESOLVER = "resolver_task"
+    TASKS_WHOIS = "whois_task"
+    TASKS_GEOIP = "geoip_task"
+
+
+class MsgValues(ConstantDict):
+    HTTP_STATUS_NONCONNECT = -1
+
 
 class MsgErrs(ConstantDict):
     INPUT_INCORRECT_FORMAT = "INPUT_INCORRECT_FORMAT::{0}"
